@@ -45,9 +45,9 @@ coordinate_criteria = {
                      'atmosphere_hybrid_height_coordinate', 'atmosphere_sleve_coordinate',
                      'height_above_geopotential_datum', 'height_above_reference_ellipsoid',
                      'height_above_mean_sea_level'},
-        'y': 'projection_y_coordinate',
+        'y': {'projection_y_coordinate', 'grid_latitude'},
         'latitude': 'latitude',
-        'x': 'projection_x_coordinate',
+        'x': {'projection_x_coordinate', 'grid_longitude'},
         'longitude': 'longitude'
     },
     '_CoordinateAxisType': {
@@ -622,7 +622,7 @@ class MetPyDataArrayAccessor:
             """Parse key using xarray utils to ensure we have dimension names."""
             if not is_dict_like(key):
                 labels = expanded_indexer(key, self.data_array.ndim)
-                key = dict(zip(self.data_array.dims, labels))
+                key = dict(zip(self.data_array.dims, labels, strict=False))
             return key
 
         def __getitem__(self, key):
@@ -810,7 +810,7 @@ class MetPyDatasetAccessor:
         if np.iterable(varname) and not isinstance(varname, str):
             # If non-string iterable is given, apply recursively across the varnames
             subset = xr.merge([self.parse_cf(single_varname, coordinates=coordinates)
-                               for single_varname in varname])
+                               for single_varname in varname], compat='no_conflicts')
             subset.attrs = self._dataset.attrs
             return subset
 
@@ -835,9 +835,10 @@ class MetPyDatasetAccessor:
 
         # Attempt to build the crs coordinate
         crs = None
-        if 'grid_mapping' in var.attrs:
-            # Use given CF grid_mapping
-            proj_name = var.attrs['grid_mapping']
+
+        # Check both raw attribute and xarray-handled and moved to encoding
+        proj_name = var.encoding.get('grid_mapping', var.attrs.get('grid_mapping'))
+        if proj_name is not None:
             try:
                 proj_var = self._dataset.variables[proj_name]
             except KeyError:
@@ -884,8 +885,10 @@ class MetPyDatasetAccessor:
                 try:
                     var = var.metpy.convert_coordinate_units(coord_name, 'meters')
                 except DimensionalityError:
-                    # Radians! Attempt to use perspective point height conversion
-                    if crs is not None:
+                    # Not strictly a length coordinate, so angle of some kind, either rotated
+                    # lat/lon or some satellite projection. Guess if we should convert to
+                    # length using the perspective point height
+                    if crs is not None and 'perspective_point_height' in crs:
                         height = crs['perspective_point_height']
                         new_coord_var = coord_var.copy(
                             data=(
@@ -1288,10 +1291,7 @@ def preprocess_and_wrap(broadcast=None, wrap_like=None, match_unit=False, to_mag
                 arg_names_to_broadcast = tuple(
                     arg_name for arg_name in broadcast
                     if arg_name in bound_args.arguments
-                    and isinstance(
-                        bound_args.arguments[arg_name],
-                        (xr.DataArray, xr.Variable)
-                    )
+                    and isinstance(bound_args.arguments[arg_name], xr.DataArray | xr.Variable)
                 )
                 broadcasted_args = xr.broadcast(
                     *(bound_args.arguments[arg_name] for arg_name in arg_names_to_broadcast)
@@ -1339,7 +1339,7 @@ def preprocess_and_wrap(broadcast=None, wrap_like=None, match_unit=False, to_mag
                     wrapping = _wrap_output_like_not_matching_units
 
                 if isinstance(match, tuple):
-                    return tuple(wrapping(*args) for args in zip(result, match))
+                    return tuple(wrapping(*args) for args in zip(result, match, strict=False))
                 else:
                     return wrapping(result, match)
         return wrapper
