@@ -31,7 +31,7 @@ def test_us_county_scales(ccrs):
     ax2 = fig.add_subplot(1, 3, 2, projection=proj)
     ax3 = fig.add_subplot(1, 3, 3, projection=proj)
 
-    for scale, axis in zip(['20m', '5m', '500k'], [ax1, ax2, ax3]):
+    for scale, axis in zip(['20m', '5m', '500k'], [ax1, ax2, ax3], strict=False):
         axis.set_extent([270.25, 270.9, 38.15, 38.75], ccrs.Geodetic())
         axis.add_feature(mpplots.USCOUNTIES.with_scale(scale))
     return fig
@@ -60,7 +60,7 @@ def test_us_states_scales(ccrs):
     ax2 = fig.add_subplot(1, 3, 2, projection=proj)
     ax3 = fig.add_subplot(1, 3, 3, projection=proj)
 
-    for scale, axis in zip(['20m', '5m', '500k'], [ax1, ax2, ax3]):
+    for scale, axis in zip(['20m', '5m', '500k'], [ax1, ax2, ax3], strict=False):
         axis.set_extent([270, 280, 28, 39], ccrs.Geodetic())
         axis.add_feature(mpplots.USSTATES.with_scale(scale))
     return fig
