@@ -18,10 +18,11 @@ from metpy.xarray import (add_vertical_dim_from_xarray, check_axis, check_matchi
                           grid_deltas_from_dataarray, preprocess_and_wrap)
 
 
-@pytest.fixture
-def test_ds():
+@pytest.fixture(params=[True, 'all'])
+def test_ds(request):
     """Provide an xarray dataset for testing."""
-    return xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+    return xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False),
+                           decode_coords=request.param)
 
 
 @pytest.fixture
@@ -47,7 +48,8 @@ def test_var(test_ds):
 def test_var_multidim_full(test_ds):
     """Provide a variable with x/y coords and multidimensional lat/lon auxiliary coords."""
     return (test_ds[{'isobaric': [6, 12], 'y': [95, 96], 'x': [122, 123]}]
-            .squeeze().set_coords(['lat', 'lon'])['Temperature'])
+            .squeeze().drop_vars('Lambert_Conformal')
+            .set_coords(['lat', 'lon'])['Temperature'])
 
 
 @pytest.fixture
@@ -251,6 +253,25 @@ def test_radian_projection_coords():
     assert data_var.coords['y'].metpy.unit_array[1] == 3 * units.meter
 
 
+def test_rotated_lat_lon():
+    """Test fallback code for radian units in projection coordinate variables."""
+    proj = xr.DataArray(0, attrs={'grid_mapping_name': 'rotated_latitude_longitude',
+                                  'grid_north_pole_latitude': 42.5,
+                                  'grid_north_pole_longitude': -277})
+    rlon = xr.DataArray(np.linspace(-33, 33, 3),
+                        attrs={'standard_name': 'grid_longitude', 'units': 'degrees'})
+    rlat = xr.DataArray(np.linspace(-27, 27, 2),
+                        attrs={'standard_name': 'grid_latitude', 'units': 'degrees'})
+    data = xr.DataArray(np.arange(6).reshape(3, 2), coords=(rlon, rlat), dims=('rlon', 'rlat'),
+                        attrs={'grid_mapping': 'rotated_pole'})
+    ds = xr.Dataset({'data': data, 'rotated_pole': proj})
+
+    # Check that the coordinates in this case are left alone
+    data_var = ds.metpy.parse_cf('data')
+    assert_array_equal(data_var.coords['rlon'], rlon)
+    assert_array_equal(data_var.coords['rlat'], rlat)
+
+
 def test_missing_grid_mapping_valid():
     """Test falling back to implicit lat/lon projection when valid."""
     lon = xr.DataArray(-np.arange(3),
@@ -676,11 +697,6 @@ def test_find_axis_number_bad_identifier(test_var):
     assert 'axis is not valid' in str(exc.value)
 
 
-def test_cf_parse_with_grid_mapping(test_var):
-    """Test cf_parse dont delete grid_mapping attribute."""
-    assert test_var.grid_mapping == 'Lambert_Conformal'
-
-
 def test_data_array_loc_get_with_units(test_var):
     """Test the .loc indexer on the metpy accessor."""
     truth = test_var.loc[:, 850.]
